@@ -44,7 +44,7 @@ class DocumentTestCase(unittest.TestCase):
         try:
             doc.bar="bla"
         except AttributeError, e:
-            self.assert_(str(e) == "bar is not defined in schema (not a valid property)")
+            self.assertEqual(str(e), "'bar' is not defined in schema (not a valid property)")
         doc.save()
         self.assert_(not hasattr(doc, "bar"))
         assert doc._doc['foo'] == "test"
@@ -59,7 +59,7 @@ class DocumentTestCase(unittest.TestCase):
         try:
             doc.bar="bla"
         except AttributeError, e:
-            self.assert_(str(e) == "bar is not defined in schema (not a valid property)")
+            self.assertEqual(str(e), "'bar' is not defined in schema (not a valid property)")
         doc.save()
         self.assert_(not hasattr(doc, "bar"))
         self.assert_(doc._doc['foo'] == "test")
@@ -213,8 +213,6 @@ class DocumentTestCase(unittest.TestCase):
 
         self.server.delete_db('couchdbkit_test')
 
-
-
     def testGet(self):
         db = self.server.create_db('couchdbkit_test')
         class Test(Document):
@@ -637,6 +635,28 @@ class DocumentTestCase(unittest.TestCase):
 
         self.server.delete_db('couchdbkit_test')
 
+    def testDocumentBulkDelete(self):
+        db = self.server.create_db('couchdbkit_test')
+
+        class Test(Document):
+            string = StringProperty()
+        Test._db = db
+
+        doc = Test()
+        doc.string = "test"
+        doc.save()
+        doc2 = Test()
+        doc2.string = "test2"
+        doc2.save()
+
+        Test.bulk_delete([doc, doc2])
+
+        for doc_id in [doc._id, doc2._id]:
+            with self.assertRaises(ResourceNotFound):
+                Test.get(doc_id)
+
+        self.server.delete_db('couchdbkit_test')
+
 
 class PropertyTestCase(unittest.TestCase):
 
